@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (C) 2016 Adrien Vergé
 #
 # This program is free software: you can redistribute it and/or modify
@@ -14,8 +13,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function
-
 import argparse
 import io
 import locale
@@ -93,6 +90,10 @@ class Format(object):
         line += 'line=' + format(problem.line) + ','
         line += 'col=' + format(problem.column)
         line += '::'
+        line += format(problem.line)
+        line += ':'
+        line += format(problem.column)
+        line += ' '
         if problem.rule:
             line += '[' + problem.rule + '] '
         line += problem.desc
@@ -103,18 +104,25 @@ def show_problems(problems, file, args_format, no_warn):
     max_level = 0
     first = True
 
+    if args_format == 'auto':
+        if ('GITHUB_ACTIONS' in os.environ and
+                'GITHUB_WORKFLOW' in os.environ):
+            args_format = 'github'
+        elif supports_color():
+            args_format = 'colored'
+
     for problem in problems:
         max_level = max(max_level, PROBLEM_LEVELS[problem.level])
         if no_warn and (problem.level != 'error'):
             continue
         if args_format == 'parsable':
             print(Format.parsable(problem, file))
-        elif args_format == 'github' or (args_format == 'auto' and
-                                         'GITHUB_ACTIONS' in os.environ and
-                                         'GITHUB_WORKFLOW' in os.environ):
+        elif args_format == 'github':
+            if first:
+                print('::group::%s' % file)
+                first = False
             print(Format.github(problem, file))
-        elif args_format == 'colored' or \
-                (args_format == 'auto' and supports_color()):
+        elif args_format == 'colored':
             if first:
                 print('\033[4m%s\033[0m' % file)
                 first = False
@@ -125,6 +133,9 @@ def show_problems(problems, file, args_format, no_warn):
                 first = False
             print(Format.standard(problem, file))
 
+    if not first and args_format == 'github':
+        print('::endgroup::')
+
     if not first and args_format != 'parsable':
         print('')
 
