@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (C) 2016 Adrien Vergé
 #
 # This program is free software: you can redistribute it and/or modify
@@ -14,6 +13,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import fileinput
 import os.path
 
 import pathspec
@@ -26,14 +26,16 @@ class YamlLintConfigError(Exception):
     pass
 
 
-class YamlLintConfig(object):
+class YamlLintConfig:
     def __init__(self, content=None, file=None):
         assert (content is None) ^ (file is None)
 
         self.ignore = None
 
         self.yaml_files = pathspec.PathSpec.from_lines(
-            'gitwildmatch', ['*.yaml', '*.yml'])
+            'gitwildmatch', ['*.yaml', '*.yml', '.yamllint'])
+
+        self.locale = None
 
         if file is not None:
             with open(file) as f:
@@ -46,7 +48,7 @@ class YamlLintConfig(object):
         return self.ignore and self.ignore.match_file(filepath)
 
     def is_yaml_file(self, filepath):
-        return self.yaml_files.match_file(filepath)
+        return self.yaml_files.match_file(os.path.basename(filepath))
 
     def enabled_rules(self, filepath):
         return [yamllint.rules.get(id) for id, val in self.rules.items()
@@ -95,7 +97,21 @@ class YamlLintConfig(object):
             except Exception as e:
                 raise YamlLintConfigError('invalid config: %s' % e)
 
-        if 'ignore' in conf:
+        if 'ignore' in conf and 'ignore-from-file' in conf:
+            raise YamlLintConfigError(
+                'invalid config: ignore and ignore-from-file keys cannot be '
+                'used together')
+        elif 'ignore-from-file' in conf:
+            if isinstance(conf['ignore-from-file'], str):
+                conf['ignore-from-file'] = [conf['ignore-from-file']]
+            if not (isinstance(conf['ignore-from-file'], list) and all(
+                    isinstance(ln, str) for ln in conf['ignore-from-file'])):
+                raise YamlLintConfigError(
+                    'invalid config: ignore-from-file should contain '
+                    'filename(s), either as a list or string')
+            with fileinput.input(conf['ignore-from-file']) as f:
+                self.ignore = pathspec.PathSpec.from_lines('gitwildmatch', f)
+        elif 'ignore' in conf:
             if not isinstance(conf['ignore'], str):
                 raise YamlLintConfigError(
                     'invalid config: ignore should contain file patterns')
@@ -111,6 +127,12 @@ class YamlLintConfig(object):
             self.yaml_files = pathspec.PathSpec.from_lines('gitwildmatch',
                                                            conf['yaml-files'])
 
+        if 'locale' in conf:
+            if not isinstance(conf['locale'], str):
+                raise YamlLintConfigError(
+                    'invalid config: locale should be a string')
+            self.locale = conf['locale']
+
     def validate(self):
         for id in self.rules:
             try:
@@ -143,7 +165,7 @@ def validate_rule_conf(rule, conf):
         options = getattr(rule, 'CONF', {})
         options_default = getattr(rule, 'DEFAULT', {})
         for optkey in conf:
-            if optkey in ('ignore', 'level'):
+            if optkey in ('ignore', 'ignore-from-file', 'level'):
                 continue
             if optkey not in options:
                 raise YamlLintConfigError(
@@ -157,11 +179,12 @@ def validate_rule_conf(rule, conf):
                     raise YamlLintConfigError(
                         'invalid config: option "%s" of "%s" should be in %s'
                         % (optkey, rule.ID, options[optkey]))
-            # Example: CONF = {option: ['flag1', 'flag2']}
-            #          → {option: [flag1]}      → {option: [flag1, flag2]}
+            # Example: CONF = {option: ['flag1', 'flag2', int]}
+            #          → {option: [flag1]}      → {option: [42, flag1, flag2]}
             elif isinstance(options[optkey], list):
                 if (type(conf[optkey]) is not list or
-                        any(flag not in options[optkey]
+                        any(flag not in options[optkey] and
+                            type(flag) not in options[optkey]
                             for flag in conf[optkey])):
                     raise YamlLintConfigError(
                         ('invalid config: option "%s" of "%s" should only '
@@ -177,6 +200,12 @@ def validate_rule_conf(rule, conf):
         for optkey in options:
             if optkey not in conf:
                 conf[optkey] = options_default[optkey]
+
+        if hasattr(rule, 'VALIDATE'):
+            res = rule.VALIDATE(conf)
+            if res:
+                raise YamlLintConfigError('invalid config: %s: %s' %
+                                          (rule.ID, res))
     else:
         raise YamlLintConfigError(('invalid config: rule "%s": should be '
                                    'either "enable", "disable" or a dict')
